@@ -16,11 +16,11 @@ import pandas as pd
 import aimlflow.utils as utils
 
 # Swami
-#BASE_URL = 'https://xh6svzuqii.execute-api.us-east-1.amazonaws.com/Navigator'
+# BASE_URL = 'https://xh6svzuqii.execute-api.us-east-1.amazonaws.com/Navigator'
 # Dev
 # BASE_URL = 'https://ygermtztdb.execute-api.us-east-1.amazonaws.com/Navigator'
 # PROD
-BASE_URL = 'https://b3005vfmhf.execute-api.us-east-1.amazonaws.com/Navigator'
+BASE_URL = 'https://apigateway.navigator.pyxeda.ai'
 
 class AiService:
     _access_token = None
@@ -463,7 +463,8 @@ class AiService:
             wait_time = 30
         url = BASE_URL + '/aiservice/feature-engineering'
         params = {
-            'reportId': fe_id
+            'reportId': fe_id,
+            'serviceId': self._service_id
         }
         while True:
             try:
@@ -497,7 +498,7 @@ class AiService:
         :param dataSourceId: Data Source Identifier (returned from uploadData).
         :param column: Label column name of the dataset.
         :param waitTime: Wait time in seconds between subsequent status checks. Default is 30 seconds.
-
+        :param problemType : type of the probelm to be analyzed; regression, classifier, auto
         .. code-block:: python
             :caption: Example using environment variables
             from aimlflow import AiService
@@ -508,6 +509,7 @@ class AiService:
             fe_params = {
                 'column' = '<label column>'
                 'waitTime' = 60
+                'problemType' = <problem type>
             }
             response = aiservice.launchFE(dataSourceId=<Data Source ID>,
                                           blocking=True,
@@ -522,15 +524,22 @@ class AiService:
         response = None
         column = None
         wait_time=None
+        problemType = None
         # serviceId, dataSourceId, column, problemType, data_type
         try:
             url = BASE_URL + '/aiservice/feature-engineering'
+            if 'problemType' in params and params['problemType']:
+                problemType = params['problemType']
             if 'column' in params and params['column']:
                 column = params['column']
             if 'dataSourceId' in params and params['dataSourceId']:
                 data_source_id = params['dataSourceId']
             else:
                 data_source_id = self._data_source_id
+            if 'feEngine' in params and params['feEngine']:
+                fe_engine = params['feEngine']
+            else:
+                fe_engine = 'aws-sklearn-serverless'
             if 'waitTime' in params and params['waitTime'] and isinstance(params['waitTime'], int):
                 wait_time = params['waitTime']
             if not column:
@@ -543,7 +552,8 @@ class AiService:
             params = {
                 'serviceId': self._service_id,
                 'dataSourceId': data_source_id,
-                'problemType': 'auto',
+                'problemType': problemType,
+                'feEngine': fe_engine,
                 'data_type': 'csv',
                 'column': column
             }
@@ -563,6 +573,32 @@ class AiService:
         return response
 
 
+    def getFE_Report(self):
+        """
+        get data prep report of FE
+        """
+        is_auth = self._check_authentication()
+        if not is_auth:
+            return None
+
+        response = None
+        try:
+            url = BASE_URL + '/dataprepreport'
+
+            params = {
+                'reportId' : self._fe_id
+            }
+            response = requests.get(url, headers=self._construct_header(), params=params)
+            response.raise_for_status()
+            response_json = response.json()
+            if (self._fe_id == response_json[self._fe_id]['report_id']):
+                print('FE Report loaded successfully with id', str(self._fe_id))
+
+        except Exception as e:
+            print('Unable to get FE Report! Error: ', str(e))
+        return response_json
+
+
     def getDeploymentStatus(self, dep_id=None, blocking=False, wait_time=None):
         is_auth = self._check_authentication()
         if not is_auth:
@@ -669,10 +705,12 @@ class AiService:
                             # print('Deployment response: ', dep_response)
                             if dep_response and dep_response['status'] in ['Completed', 'ready']:
                                 utils.color_print('Training successfully completed!', 'GREEN')
+                                print("training mode: " + response_json[train_id]['launch_mode'] )
 
                             return utils.expand_all_response(response_json[train_id])
                         else:
                             utils.color_print('Training job successfully completed', 'GREEN')
+                            print("training mode: " + response_json[train_id]['launch_mode'] )
                             return utils.expand_all_response(response_json[train_id])
                 time.sleep(wait_time)
                 if not blocking:
@@ -684,12 +722,11 @@ class AiService:
         return response
 
 
-
-    def launchTrain(self, params):
+    def launchTrain(self, train_params):
         """
         Launch a Training experiment.
         :param fe_id: Feature Engineering Identifier (returned from launchFE).
-        :param launchMode: The mode to run the train experiment. In the current version, only 'automatic' is supported.
+        :param launchMode: The mode to run the train experiment.
         :param waitTime: Wait time in seconds between subsequent status checks. Default is 30 seconds.
 
         .. code-block:: python
@@ -699,55 +736,73 @@ class AiService:
             aiservice = AiService.AiService()
             ...
 
-            fe_params = {
-                'column' = '<label column>'
+            train_params = {
+                'fe_id': '<feature engineering ID>', #optional
+                'launchMode' = '<automatic/semi-automatic>',
+                'engine': '<aws-sklearn-serverless/aws-sagemaker>'
                 'waitTime' = 60
             }
-            response = aiservice.launchTrain(fe_id=<Feature engineering ID>,
-                                             launchMode='automatic',
-                                             engine='aws-sklearn-serverless',
-                                             waitTime=30)
+            response = aiservice.launchTrain(train_params)
             print('Train Status: ', response['status'])
             print('Train Details: ', response)
         """
+
         is_auth = self._check_authentication()
         if not is_auth:
             return None
 
         response = None
+        hyper_params = None
+
         # serviceId, dataSourceId, column, problemType, data_type
         try:
             column = None
             url = BASE_URL + '/train'
-            if 'fe_id' in params and params['fe_id']:
-                fe_id = params['fe_id']
+
+            if 'fe_id' in train_params and train_params['fe_id']:
+                fe_id = train_params['fe_id']
             else:
                 fe_id = self._fe_id
-            if 'launchMode' in params:
-                launch_mode = params['launchMode']
+
+            if 'launchMode' in train_params:
+                launch_mode = train_params['launchMode']
             else:
                 launch_mode = 'automatic'
-            if 'engine' in params:
-                engine = params['engine']
+
+            if 'engine' in train_params:
+                engine = train_params['engine']
             else:
                 engine = 'aws-sklearn-serverless'
+
             if engine not in ['aws-sklearn-serverless', 'aws-sagemaker']:
                 print('Please provide a valid ML (aws-sklearn-serverless/aws-sagemaker) engine!')
                 return None
-            if 'waitTime' in params and params['waitTime'] and isinstance(params['waitTime'], int):
-                wait_time = params['waitTime']
 
+            if 'waitTime' in train_params and train_params['waitTime'] and isinstance(train_params['waitTime'], int):
+                wait_time = train_params['waitTime']
+            else:
+                wait_time = 60
+
+            # Check if there are hyper paramers
+            if 'params' in train_params and train_params['params']:
+                hyper_params = train_params['params']
             if not fe_id:
-                print('Unable to Train! Feature engineering id (params[\"fe_id\"]) was not provided!')
+                print('Unable to Train! Feature engineering id (train_params[\"fe_id\"]) was not provided!')
+                return response
+            if hyper_params and launch_mode == 'automatic':
+                print('Unable to Launch Train! (train_params[\"params\"]) can only be used with train_params[\"launchMode\"] = \"semi-automatic\"!')
                 return response
 
-            params = {
+            body = {
                 'serviceId': self._service_id,
                 'reportId': fe_id,
                 'launchMode': launch_mode,
                 'mode': engine
             }
-            response = requests.post(url, headers=self._construct_header(), json=params)
+            if hyper_params:
+                body['params'] = hyper_params
+
+            response = requests.post(url, headers=self._construct_header(), json=body)
             # print('URL response: ', response.json())
             response_json = response.json()
 
@@ -763,6 +818,67 @@ class AiService:
         return response
 
 
+
+    def fetchTrainParams(self, params):
+        """
+        Fetch the Training experiment parameters to launch semi-automatic training.
+        :param fe_id: Feature Engineering Identifier (returned from launchFE).
+        :param engine: The engine to run the train experiment.
+
+        .. code-block:: python
+            :caption: Example using environment variables
+            from aimlflow import AiService
+
+            aiservice = AiService.AiService()
+            ...
+
+            params = {
+                'feId': '<fe_id>'   # optional
+                'engine' = '<aws-sklearn-serverless/aws-sagemaker>'
+            }
+            response = aiservice.fetchTrainParams(params)
+            print('Train Params: ', response)
+        """
+        is_auth = self._check_authentication()
+        if not is_auth:
+            return None
+
+        response = None
+        # serviceId, dataSourceId, column, problemType, data_type
+        try:
+            column = None
+            url = BASE_URL + '/train/params'
+            if 'fe_id' in params and params['fe_id']:
+                fe_id = params['fe_id']
+            else:
+                fe_id = self._fe_id
+            if 'engine' in params:
+                engine = params['engine']
+            else:
+                engine = 'aws-sklearn-serverless'
+            if engine not in ['aws-sklearn-serverless', 'aws-sagemaker']:
+                print('Please provide a valid ML (aws-sklearn-serverless/aws-sagemaker) engine!')
+                return None
+            if not fe_id:
+                print('Unable to Fetch the Train Parameters! Feature engineering id (params[\"fe_id\"]) was not provided!')
+                return response
+
+            params = {
+                'serviceId': self._service_id,
+                'reportId': fe_id,
+                'mode': engine,
+                'isUI': 'False'
+            }
+            response = requests.get(url, headers=self._construct_header(), params=params)
+            # print('URL response: ', response.json())
+            response_json = response.json()
+
+        except Exception as e:
+            print('Unable to fetch Train Parameters! Error: ', str(e))
+        return response_json
+
+
+
     def getServiceDetails(self, service_name=None):
         is_auth = self._check_authentication()
         if not is_auth:
@@ -778,7 +894,7 @@ class AiService:
             response = requests.get(url, headers=self._construct_header(), params=params)
             response.raise_for_status()
 
-            # print('Response: ', response)
+            # print('Response: ', response) 
             response_json = response.json()
             # print('Json: ', response_json)
             ids = list(response_json.keys())
@@ -788,6 +904,7 @@ class AiService:
             print('Unable to fetch the service details! Error: ', str(e))
             return None
 
+
     def getEndpointURL(self, service_name=None):
         """
         Get the endpoint (or model serving) URL of the AI Service
@@ -799,8 +916,7 @@ class AiService:
             from aimlflow import AiService
 
             aiservice = AiService.AiService()
-            ...
-
+        ..
             response = aiservice.getEndpointURL()
             print('Endpoint URL: ', response)
         """
@@ -819,4 +935,118 @@ class AiService:
             return endpoint_url
         except Exception as e:
             print('Unable to get the endpoint details! Error:', str(e))
-            return None
\ No newline at end of file
+            return None
+
+
+    def deleteService(self, service_id=None):
+        """
+        Delete an AI Service.
+        :param name: Name of the service.
+
+        .. code-block:: python
+            :caption: Example using environment variables
+            from aimlflow import AiService
+
+            aiservice = AiService.AiService()
+            # Assuming already authenticated
+        ..
+            response = aiservice.deleteService(name='my_ai_service')
+            print('service: ', response)
+
+        """
+        is_auth = self._check_authentication()
+        if not is_auth:
+            return False
+        if not service_id:
+            service_id = self._service_id
+        if not service_id:
+            return None
+
+        response = False
+        try:
+            url = BASE_URL + '/deploy/nullmodel'
+            params = {'serviceId': service_id}
+            response = requests.delete(url, headers=self._construct_header(), params=params)
+            # If the response was successful, no Exception will be raised
+            response.raise_for_status()
+
+            try:
+                response_json = response.json()
+            except Exception as e:
+                utils.color_print('AI Service deletion failed!. Service with the name does not', 'RED')
+                return None
+
+            # print('Json: ', response_json)
+            result = response_json['result']
+            service_id = response_json['serviceId']
+            return result
+        except HTTPError as http_err:
+            print('AI Service Deletion failed!')
+        except Exception as e:
+            print('Unable to Delete the AI Service! Error: ', str(e))
+        return None
+
+
+    def importData(self, **kwargs):
+        is_auth = self._check_authentication()
+        if not is_auth:
+            return None
+
+        response = None
+        try:
+            file_location = None
+            if 'fileLocation' in kwargs:
+                file_location = kwargs['fileLocation']
+            if 'cloud' in kwargs:
+                cloud = kwargs['cloud']
+                if cloud != 'AWS':
+                    utils.color_print('{} is not yet supported!'.format(cloud), 'RED')
+                    return None
+            else:
+                cloud = 'AWS'
+
+            bucket = None
+            if 'bucket' in kwargs:
+                bucket = kwargs['bucket']
+            else:
+                bucket = self._username
+
+            # Import the data and get a data id
+            import_params = {
+                'serviceName': self._service_name,
+                'location': {'bucket': bucket, 'key': kwargs['fileLocation']},
+                'dataType': 'csv',
+                'cloud': 'AWS',
+                'source': 's3',
+            }
+            response = self._importData(import_params)
+            if not response:
+                utils.color_print('Unable to import the uploaded dataset!', 'RED')
+                return None
+            elif response['result'] == "success":
+                print("successfully imported data from s3 " + bucket )
+
+        except Exception as e:
+            print('Unable to upload data! Error: ', str(e))
+        return response
+
+
+    def get_prediction(self,data):
+        """
+        Get the prediction for a given param in the current ai service
+        :param data : request paramters for a given ai
+        e.g : {"sentence":"I am sad."} in mood test ai
+        """
+        endpoint_url = self.getEndpointURL()
+        result_json = None
+        try:
+            r = requests.post(endpoint_url, data=json.dumps(data))
+            response = getattr(r,'_content').decode("utf-8")
+            response_json = json.loads(response)
+            print(response_json)
+            result_str = response_json['body']
+            result_json = json.loads(result_str)
+        except Exception as e:
+            print('Unable to get prediction!, Error: ', str(e))
+
+        return result_json
